@@ -25,26 +25,28 @@ from cmd2 import (
 
 DC_TOOLS = [ 'system-tools', 'dev-tools', 'app-services','dataset-services','dl-model-services','dl-model-training-services',
                 'dlstreamer-pipeline-services','edge-deployment-services','edge-inference-app-services',
-                'edge-to-cloud-app-services','k8s-services','intel-dev-tools','oneapi-toolkits','one-edge-building-blocks']
+                'edge-to-cloud-app-services','k8s-services','intel-dev-tools','oneapi-toolkits','one-edge-building-blocks',
+                'cloud-native-tools']
 DC_COMMANDS = ['install', 'uninstall']
 DC_COMMANDS_WE = ['install', 'uninstall', 'enable', 'disable']
 APP_COMMANDS = ['start', 'stop', 'restart']
 
 SUB_TOOLS={
   "system-tools":['sftp', 'ssh', 'vnc', 'no-machine','vim'],
-  "dev-tools":['code-editor-tools','container-runtimes','automation-and-configuration-tools'],
+  "dev-tools":['code-editor-tools','container-runtimes'],
   "app-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics'],  
   "dataset-services":['intel','partner','public','synthetic'],
   "dl-model-services":['dl-model-tools', 'inference-runtimes','featured-dl-models'],
-  "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-frameworks'],
+  "dl-model-training-services":['data-engineering-tools', 'datasets', 'model-zoo', 'training-frameworks','ai-reference-kits'],
   "dlstreamer-pipeline-services":['audio-pipelines','dlstreamer-tools','multi-sensory-pipelines','video-pipelines'],
   "edge-deployment-services":['cross-plane','health-check','mass','vpshere-vm'],
   "edge-inference-app-services":['healthcare','industrial','market-places','media','retail','safety-security','transportation'],
   "edge-to-cloud-app-services":['seo-samples','seo-reference-implementations','seo-3rd-party-applications'],
-  "k8s-services":['kind','kubespray','microk8s','kubeadm','minikube','openshift','rancher-k3s','rancher-rke2','smart-edge-open','starlingx','tanzu'],
+  "k8s-services":['aether','kind','kubespray','microk8s','kubeadm','minikube','openshift','rancher-k3s','rancher-rke2','smart-edge-open','starlingx','tanzu'],
   "intel-dev-tools":['intel-auto-deploy','intel-auto-test','intel-code-scans','mgt-console'],
   "oneapi-toolkits":['ai-analytics-toolkit','base-toolkit','intel-vtune','iot-toolkit','scikit-learn','xgboost'],
-  "one-edge-building-blocks":['csp-services','inference-services','observability-services']
+  "one-edge-building-blocks":['csp-services','inference-services','observability-services'],
+  "cloud-native-tools" :['automation-tools','cd-tools','ci-tools','iac-tools','observability-tools']
 }
 
 TOOLS={
@@ -55,29 +57,31 @@ TOOLS={
                     'post-training-optimization-toolkit'],
   "inference-runtimes":['intel-optimized-pytorch', 'intel-optimized-tensorflow','onnx', 'openvino-2022.1', 'openvino-addon-tensorflow'],
   "featured-dl-models":['bert-large-uncased-whole-word-masking-squad-int8-0001','deeplabv3','efficientdet-d0-tf','facenet-20180408-102900','mobilenet-ssd','object-detection-models','resnet-50-pytorch','ssdlite_mobilenet_v2','yolo-v4-tf'],
-  "model-zoo":['pytorch-model-zoo','tensorflow-hub','intel-ai-model-zoo','intel-openvino-model-zoo'],
+  "model-zoo":['pytorch-model-zoo','tensorflow-hub'],
   "data-engineering-tools":['cvat','datumaro'],
   "datasets":['face-detection','face-mask-detection','fake-face-detection','flowers-recognition'],
+  "ai-reference-kits":['customer-chatbot','intelligent-indexing','predictive-health-analytics','visual-quality-inspection'],
   "object-detection-models":['face-detection-retail-0005','pedestrian-detection-adas-0002','person-detection-retail-0002','vehicle-detection-adas-0002'],
   "object-recognition-models":['age-gender-recognition-retail-0013','head-pose-estimation-adas-0001'],
-  "training-frameworks":['intel-optimized-pytorch','intel-optimized-tensorflow','kubeflow','openvino-training-extensions','sonoma-creek','sigopt','bigdl'],
+  "training-frameworks":['intel-optimized-pytorch','intel-optimized-tensorflow','kubeflow','openvino-training-extensions','sonoma-creek','sigopt','bigdl','cnvrg'],
   "dlstreamer-tools":['dlstreamer-pipeline-framework','dlstreamer-pipeline-server','dlstreamer-pipeline-zoo','dlstreamer-pipeline-benchmark','gst-shark'],
   "audio-pipelines":['audio-event-detection-sample'],
-  "video-pipelines":['action-recognition-sample','human-pose-estimation-sample','vehicle-pedestrian-tracking-sample','face-detection-classification-sample','gvapython-sample','metadata-publishing-sample'],
+  "video-pipelines":['action-recognition-sample','human-pose-estimation-sample','vehicle-pedestrian-tracking-sample','face-detection-classicification-sample','gvapython-sample','metadata-publishing-sample'],
   "multi-sensory-pipelines":['multi-sensor-pipeline'],
   "healthcare":['brain-tumor-segmentation','monai','openfl'],
   "industrial":['edge-controls-for-industrial','edge-insights-for-amr','edge-insights-for-industrial','industrial-surface-defect-detection','industrial-textline-recognition','rotor-bearing-defect-detector','textile-defect-classifier','weld-porosity-detection'],
   "market-places":['artifactory','dev-catalog','kube-apps','mrs','rrk'],
   "media":['ad-insertion','cdn-transcode-sample','immersive-video-sample','open-visual-cloud','smart-city','video-curation-sample'],
   "retail":['automated-checkout','edgex','interactive-kisok-ai-chatbot','real-time-sensor-fusion-for-loss-detection','social-distancing-for-retail-settings'],
-  "safety-security":['edge-aibox-for-video-analytics','edge-insights-for-vision','smart-video-and-ai-workload','social-distancing-for-retail','social-distancing-for-retail-settings'],
+  "safety-security":['edge-aibox-for-video-analytics','edge-insights-for-vision','smart-video-and-ai-workload','social-distancing-for-retail-settings'],
   "transportation":['address-recognition-and-analytics','automatic-license-plate-recognition','cargo-management','drive-behavior-analytics','edge-insights-for-fleet','intelligent-traffic-management','public-transit-analytics','vehicle-event-recording','workzone-analytics'],
-  "seo-samples":['sample-cdn-application','smart-city-app','telemetry-sample-app','video-anlaytics-services-sample'],
+  "seo-samples":['openvino-sample-application-in-openness','sample-eaa-test-application','telemetry-sample','video-analytics-services-sample-application-in-openness'],
   "seo-reference-implementations":['intelligent-connection-management-for-automated-handover','smartvr–livestreaming-of-immersive-media','telehealth-remote-monitoring','wireless-network-ready-intelligent-traffic-management','wireless-network-ready-pcb-defect-detection','network-optimization-and-ai-inferencing-management-for-telepathology'],
   "seo-3rd-party-applications":['a5gnetworks','herta','orbo','qwilt','radisys'],
   "csp-services":['aws-greengrass','azure-iot-central','azure-iot-edge','azure-iot-hub'],
   "inference-services":['dlstreamer','dlstreamer-pipeline-server','openvino-container','openvino-model-server'],
-  "observability-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics']
+  "observability-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics'],
+  "automation-tools":['ansible','chef','puppet'] 
 
 }
 
