@@ -43,6 +43,6 @@ echo -e "\e[1;34mMONAI folder is downloaded in \home\intel\<username>\e[0m\n"
 
 #Check RI is installed sucessfully
 
-echo -e "\e[1;32m\nIf RI installed suceessfully...\e[0m"
+echo -e "\e[1;32m\nIf RI installed successfully...\e[0m"
 echo -e "\e[1;36mFor further development refer below URL\e[0m"
 echo -e "\e[1;33mhttps://github.com/Project-MONAI/MONAI\e[0m\n"
