@@ -30,6 +30,6 @@ echo -e "\e[1;34mWork_Zone_Analytics_<version> folder is downloaded in \home\int
 
 #Check RI is installed sucessfully
 
-echo -e "\e[1;32m\nIf workzone-analytics RI installed suceessfully...\e[0m"
+echo -e "\e[1;32m\nIf workzone-analytics RI installed successfully...\e[0m"
 echo -e "\e[1;36mFor further development refer below URL\e[0m"
 echo -e "\e[1;33mhttps://www.intel.com/content/www/us/en/developer/articles/reference-implementation/work-zone-analytics.html\e[0m\n"
